﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using DlhSoft.Windows.Data;
using DlhSoft.Windows.Controls;

namespace LoadChartViewNumericDaysSample
{
    /// <summary>
    /// Interaction logic for Window1.xaml
    /// </summary>
    public partial class Window1 : Window
    {
        public Window1()
        {
            InitializeComponent();
        }

        // Prepare all days schedule, numeric weeks time scale, and numeric week and numeric day time scale text format instances to be used as specific scale-related settings.
        public static Schedule AllDaysSchedule
        {
            get
            {
                return new Schedule("All days",
                    delegate(Date date)
                    {
                        return new TimeIntervalCollection
                        {
                            new TimeInterval(date.Add(TimeSpan.Zero), date.Add(TimeSpan.Parse("08:00:00"))),
                        };
                    });
            }
        }
        public static TimeScale NumericWeeksTimeScale
        {
            get
            {
                // Defines a time scale that is based on simmulated time scale periods of 5 working days.
                return new TimeScale(
                    delegate(DateTime start, DateTime finish)
                    {
                        // Get the next scale period start.
                        start = start.Date.AddDays(5 - (int)(start.Date - DateTime.MinValue).TotalDays % 5);
                        // Prepare and return the list of time scale items based on the provided date and times.
                        SortedList<DateTime, string> timeScaleItems = new SortedList<DateTime, string>();
                        for (DateTime dateTime = start; dateTime <= finish; dateTime = dateTime.AddDays(5))
                            timeScaleItems.Add(dateTime, null);
                        return timeScaleItems;
                    });
            }
        }
        public static TimeScaleTextFormat NumericWeekTimeScaleTextFormat
        {
            get
            {
                // Defines a time scale text format that returns simmulated week numbers, counting from the project start date (DateTime.MinValue).
                return new TimeScaleTextFormat(
                    delegate(DateTime dateTime)
                    {
                        // Prepare and return the string to be displayed based on the provided date and time.
                        return string.Format("Week {0}", ((int)(dateTime.Date - DateTime.MinValue).TotalDays / 5 + 1));
                    });
            }
        }
        public static TimeScaleTextFormat NumericDayTimeScaleTextFormat
        {
            get
            {
                // Defines a time scale text format that returns simmulated day numbers, counting from the project start date (DateTime.MinValue).
                return new TimeScaleTextFormat(
                    delegate(DateTime dateTime)
                    {
                        // Prepare and return the string to be displayed based on the provided date and time.
                        return (((int)(dateTime.Date - DateTime.MinValue).TotalDays) % 500 + 1).ToString();
                    });
            }
        }
    }
}
